const fs = require('fs');
const path = require('path');
const isDir = (url) => {
    if (fs.existsSync(url)) {
        const stat = fs.statSync(url);
        return stat.isDirectory();
    } else {
        return false;
    }
}
const addFile = (url, data)=>{
    return new Promise((resolve) => {
        try {
            fs.writeFileSync(url, data,{encoding:'utf8'});
            resolve(true);
        } catch (err) {
            resolve(false);
        }
    })
}
module.exports = {
    isDir,
    addFile,
    isFile(url) {
        if (fs.existsSync(url)) {
            const stats = fs.statSync(url);
            return stats.isFile();
        } else {
            return false;
        }
    },
    addJson(url,data){
        return addFile(url,JSON.stringify(data));
    },
    readJson(url){
        return new Promise((resolve) => {
            fs.readFile(url, 'utf8', (err, data) => {
                if (!err) {
                    if(data) {
                        resolve(JSON.parse(data))
                    }else{
                        resolve('')
                    }
                }else{
                    resolve(null)
                }
            });
        })
    },
    readFile(url) {
        return new Promise((resolve) => {
            fs.readFile(url, 'utf8', (err, data) => {
                if (!err) {
                    resolve(data)
                }else{
                    resolve(null)
                }
            });
        })
    },
    dirFile(paths) {
        let obj = {};
        obj[paths] = 'dir';
        const arrFile = (url) => {
            const item = fs.readdirSync(url);
            if (item.length > 0) {
                let dir = [];
                item.forEach(e => {
                    const ets = path.resolve(url, e);
                    if (isDir(ets)) {
                        dir.push(ets);
                        obj[ets] = 'dir';
                    } else {
                        obj[ets] = 'file';
                    }
                });
                for (let i = 0; i < dir.length; i++) {
                    arrFile(dir[i]);
                };
            }
        }
        arrFile(paths);
        return obj;
    },
    addDir(url) {
        return new Promise((resolve) => {
            fs.mkdir(url, e => {
                if (e) {
                    resolve(false);
                } else {
                    resolve(true);
                }
            })
        })
    },
    delFile(url) {
        return new Promise((resolve) => {
            fs.unlink(url, e => {
                if (e) {
                    resolve(false);
                } else {
                    resolve(true);
                }
            })
        })
    },
    getSize(obj) {
        let size = 0;
        for (const key in obj) {
            if (obj[key] === 'file') {
                size += fs.statSync(key).size;
            }
        }
        return size
    },
    copyFile(old, news, def) {
        return new Promise((resolve) => {
            // 创建可读流来读取源文件
            const oldStream = fs.createReadStream(old);
            // 创建可写流来写入目标文件
            const newStream = fs.createWriteStream(news);
            // 使用管道将源文件的流复制到目标文件流中
            oldStream.pipe(newStream);
            // 处理错误和结束事件
            oldStream.on('data', (data) => {
                if (def) def(data.length);
            })
            oldStream.on('error', () => {
                newStream.close();
                resolve(false);
            });
            newStream.on('error', () => {
                oldStream.close();
                resolve(false);
            });
            // 当源文件流结束时，表示复制完成，可以处理结束事件
            oldStream.on('end', () => {
                resolve(true);
            });
        })
    }
}